==> homescreen-dockbar_0.0.5.tar.gz: homescreen-dockbar-0.0.5/settings.cpp <==
#include "settings.h"
#include "home.h"
#include "ui_settings.h"
#include "items.h"
#include <QSettings>
#include <QFile>
#include <QTextStream>
#include <QFileInfo>

#include <glib-2.0/glib-object.h>
//#include <libhildondesktop-1/libhildondesktop/libhildondesktop.h>
#include <libintl.h>
#include <locale.h>
#include <string.h>
#include "locale.h"
//#include <gtk-2.0/gtk/gtk.h>
#include <gtk-2.0/gtk/gtkicontheme.h>

QString tem1, tem2;
QStringList programas;

Settings::Settings(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::Settings)
{
    ui->setupUi(this);

    LoadAll();


}

void Settings::LoadAll()
{
    QSettings settings("cepiperez","homescreen-dockbar");
    programas = settings.value("Programs",QStringList()).toStringList();

    if ( settings.value("Background","NO") == "NO" )
        ui->checkBox->setChecked(false);
    else
        ui->checkBox->setChecked(true);

    if ( settings.value("Autorotation","NO") == "NO" )
        ui->checkBox_2->setChecked(false);
    else
        ui->checkBox_2->setChecked(true);

    if ( settings.value("Vertical","NO") == "NO" )
        ui->checkBox_3->setChecked(false);
    else
        ui->checkBox_3->setChecked(true);

    if ( (programas.count() > 0) && (programas.at(0) != "") )
    {
        GetProgram(programas.at(0));
        ui->pushButton->setText(tem1);
        ui->pushButton->setIcon(QIcon(tem2));
    }
    else
    {
        ui->pushButton->setText("");
        ui->pushButton->setIcon(QIcon());
    }

    if ( (programas.count() > 1) && (programas.at(1) != "") )
    {
        GetProgram(programas.at(1));
        ui->pushButton_2->setText(tem1);
        ui->pushButton_2->setIcon(QIcon(tem2));
    }
    else
    {
        ui->pushButton_2->setText("");
        ui->pushButton_2->setIcon(QIcon());
    }

    if ( (programas.count() > 2) && (programas.at(2) != "") )
    {
        GetProgram(programas.at(2));
        ui->pushButton_3->setText(tem1);
        ui->pushButton_3->setIcon(QIcon(tem2));
    }
    else
    {
        ui->pushButton_3->setText("");
        ui->pushButton_3->setIcon(QIcon());
    }

    if ( (programas.count() > 3) && (programas.at(3) != "") )
    {
        GetProgram(programas.at(3));
        ui->pushButton_4->setText(tem1);
        ui->pushButton_4->setIcon(QIcon(tem2));
    }
    else
    {
        ui->pushButton_4->setText("");
        ui->pushButton_4->setIcon(QIcon());
    }

    if ( (programas.count() > 4) && (programas.at(4) != "") )
    {
        GetProgram(programas.at(4));
        ui->pushButton_5->setText(tem1);
        ui->pushButton_5->setIcon(QIcon(tem2));
    }
    else
    {
        ui->pushButton_5->setText("");
        ui->pushButton_5->setIcon(QIcon());
    }

    if ( (programas.count() > 5) && (programas.at(5) != "") )
    {
        GetProgram(programas.at(5));
        ui->pushButton_6->setText(tem1);
        ui->pushButton_6->setIcon(QIcon(tem2));
    }
    else
    {
        ui->pushButton_6->setText("");
        ui->pushButton_6->setIcon(QIcon());
    }

    if ( (programas.count() > 6) && (programas.at(6) != "") )
    {
        GetProgram(programas.at(6));
        ui->pushButton_7->setText(tem1);
        ui->pushButton_7->setIcon(QIcon(tem2));
    }
    else
    {
        ui->pushButton_7->setText("");
        ui->pushButton_7->setIcon(QIcon());
    }

    if ( (programas.count() > 7) && (programas.at(7) != "") )
    {
        GetProgram(programas.at(7));
        ui->pushButton_8->setText(tem1);
        ui->pushButton_8->setIcon(QIcon(tem2));
    }
    else
    {
        ui->pushButton_8->setText("");
        ui->pushButton_8->setIcon(QIcon());
    }

    if ( (programas.count() > 8) && (programas.at(8) != "") )
    {
        GetProgram(programas.at(8));
        ui->pushButton_9->setText(tem1);
        ui->pushButton_9->setIcon(QIcon(tem2));
    }
    else
    {
        ui->pushButton_9->setText("");
        ui->pushButton_9->setIcon(QIcon());
    }

    if ( (programas.count() > 9) && (programas.at(9) != "") )
    {
        GetProgram(programas.at(9));
        ui->pushButton_10->setText(tem1);
        ui->pushButton_10->setIcon(QIcon(tem2));
    }
    else
    {
        ui->pushButton_10->setText("");
        ui->pushButton_10->setIcon(QIcon());
    }


}

Settings::~Settings()
{
    delete ui;
}

void Settings::GetProgram(QString file)
{
    QSettings settings("/usr/share/applications/hildon/" + file + ".desktop", QSettings::IniFormat);
    settings.beginGroup("Desktop Entry");
    QString name = settings.value("Name", "no name").toString();
    QString icon = settings.value("Icon", "no icon").toString();
    QString domain("maemo-af-desktop");
    if(settings.contains("X-Text-Domain"))
        domain = settings.value("X-Text-Domain").toString();
    name = QString::fromUtf8(dgettext(domain.toLatin1(), name.toLatin1()));


    QSettings settings2("/etc/hildon/theme/index.theme", QSettings::IniFormat);
    settings2.beginGroup("X-Hildon-Metatheme");
    QString tema = settings2.value("IconTheme", "hicolor").toString();
    tema = tema.trimmed();

    QString icono;
    if ( QFileInfo("/usr/share/icons/" + tema + "/64x64/hildon/" + icon + ".png").exists() )
        icono = "/usr/share/icons/" + tema + "/64x64/hildon/" + icon + ".png";
    else if ( QFileInfo("/usr/share/icons/" + tema + "/64x64/apps/" + icon + ".png").exists() )
        icono = "/usr/share/icons/" + tema + "/64x64/apps/" + icon + ".png";
    else if ( QFileInfo("/usr/share/icons/" + tema + "/48x48/hildon/" + icon + ".png").exists() )
        icono = "/usr/share/icons/" + tema + "/48x48/hildon/" + icon + ".png";
    else if ( QFileInfo("/usr/share/icons/" + tema + "/48x48/apps/" + icon + ".png").exists() )
        icono = "/usr/share/icons/" + tema + "/48x48/apps/" + icon + ".png";
    else if ( QFileInfo("/usr/share/icons/" + tema + "/scalable/hildon/" + icon + ".png").exists() )
        icono = "/usr/share/icons/" + tema + "/scalable/hildon/" + icon + ".png";
    else if ( QFileInfo("/usr/share/icons/" + tema + "/scalable/apps/" + icon + ".png").exists() )
        icono = "/usr/share/icons/" + tema + "/scalable/apps/" + icon + ".png";

    else if ( QFileInfo("/usr/share/icons/hicolor/64x64/hildon/" + icon + ".png").exists() )
        icono = "/usr/share/icons/hicolor/64x64/hildon/" + icon + ".png";
    else if ( QFileInfo("/usr/share/icons/hicolor/64x64/apps/" + icon + ".png").exists() )
        icono = "/usr/share/icons/hicolor/64x64/apps/" + icon + ".png";
    else if ( QFileInfo("/usr/share/icons/hicolor/48x48/hildon/" + icon + ".png").exists() )
        icono = "/usr/share/icons/hicolor/48x48/hildon/" + icon + ".png";
    else if ( QFileInfo("/usr/share/icons/hicolor/48x48/apps/" + icon + ".png").exists() )
        icono = "/usr/share/icons/hicolor/48x48/apps/" + icon + ".png";
    else if ( QFileInfo("/usr/share/icons/hicolor/scalable/hildon/" + icon + ".png").exists() )
        icono = "/usr/share/icons/hicolor/scalable/hildon/" + icon + ".png";
    else if ( QFileInfo("/usr/share/icons/hicolor/scalable/apps/" + icon + ".png").exists() )
        icono = "/usr/share/icons/hicolor/scalable/apps/" + icon + ".png";

    else if ( QFileInfo("/usr/share/pixmaps/" + icon + ".png").exists() )
        icono = "/usr/share/pixmaps/" + icon + ".png";
    else if ( QFileInfo("/opt/maemo/usr/share/pixmaps/" + icon + ".png").exists() )
        icono = "/opt/maemo/usr/share/pixmaps/" + icon + ".png";
    else icono = "/usr/share/icons/hicolor/64x64/hildon/tasklaunch_default_application.png";

    tem1 = name;
    tem2 = icono;


}


void Settings::on_pushButton_clicked()
{
    Items* it = new Items(0,0);
    it->exec(); it->close(); LoadAll();
}

void Settings::on_pushButton_2_clicked()
{
    Items* it = new Items(0,1);
    it->exec(); it->close(); LoadAll();
}

void Settings::on_pushButton_3_clicked()
{
    Items* it = new Items(0,2);
    it->exec(); it->close(); LoadAll();
}

void Settings::on_pushButton_4_clicked()
{
    Items* it = new Items(0,3);
    it->exec(); it->close(); LoadAll();
}

void Settings::on_pushButton_5_clicked()
{
    Items* it = new Items(0,4);
    it->exec(); it->close(); LoadAll();
}

void Settings::on_pushButton_6_clicked()
{
    Items* it = new Items(0,5);
    it->exec(); it->close(); LoadAll();
}

void Settings::on_pushButton_7_clicked()
{
    Items* it = new Items(0,6);
    it->exec(); it->close(); LoadAll();
}

void Settings::on_pushButton_8_clicked()
{
    Items* it = new Items(0,7);
    it->exec(); it->close(); LoadAll();
}

void Settings::on_pushButton_9_clicked()
{
    Items* it = new Items(0,8);
    it->exec(); it->close(); LoadAll();
}

void Settings::on_pushButton_10_clicked()
{
    Items* it = new Items(0,9);
    it->exec(); it->close(); LoadAll();
}


void Settings::on_checkBox_stateChanged(int )
{
    QSettings settings("cepiperez","homescreen-dockbar");
    if ( ui->checkBox->isChecked() )
        settings.setValue("Background","YES");
    else
        settings.setValue("Background","NO");
    settings.sync();
}

void Settings::on_pushButton_11_clicked()
{
    Home* hw = new Home(this, "Backimage", "/home/user/MyDocs");
    hw->exec();
}

void Settings::on_checkBox_2_stateChanged(int )
{
    QSettings settings("cepiperez","homescreen-dockbar");
    if ( ui->checkBox_2->isChecked() )
        settings.setValue("Autorotation","YES");
    else
        settings.setValue("Autorotation","NO");
    settings.sync();
}

void Settings::on_checkBox_3_stateChanged(int )
{
    QSettings settings("cepiperez","homescreen-dockbar");
    if ( ui->checkBox_3->isChecked() )
        settings.setValue("Vertical","YES");
    else
        settings.setValue("Vertical","NO");
    settings.sync();
}

==> homescreen-dockbar_0.0.6.tar.gz: homescreen-dockbar-0.0.6/settings.cpp <==
#include "settings.h"
#include "home.h"
#include "ui_settings.h"
#include "items.h"
#include <QSettings>
#include <QFile>
#include <QTextStream>
#include <QFileInfo>

#include <glib-2.0/glib-object.h>
//#include <libhildondesktop-1/libhildondesktop/libhildondesktop.h>
#include <libintl.h>
#include <locale.h>
#include <string.h>
#include "locale.h"
//#include <gtk-2.0/gtk/gtk.h>
#include <gtk-2.0/gtk/gtkicontheme.h>

QString tem1, tem2;
QStringList programas;

Settings::Settings(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::Settings)
{
    ui->setupUi(this);

    LoadAll();


}

void Settings::LoadAll()
{
    QSettings settings("cepiperez","homescreen-dockbar");
    programas = settings.value("Programs",QStringList()).toStringList();

    if ( settings.value("Background","NO") == "NO" )
        ui->checkBox->setChecked(false);
    else
        ui->checkBox->setChecked(true);

    if ( settings.value("Autorotation","NO") == "NO" )
        ui->checkBox_2->setChecked(false);
    else
        ui->checkBox_2->setChecked(true);

    if ( settings.value("Vertical","NO") == "NO" )
        ui->checkBox_3->setChecked(false);
    else
        ui->checkBox_3->setChecked(true);

    if ( (programas.count() > 0) && (programas.at(0) != "") )
    {
        GetProgram(programas.at(0));
        ui->pushButton->setText(tem1);
        ui->pushButton->setIcon(QIcon(tem2));
    }
    else
    {
        ui->pushButton->setText("");
        ui->pushButton->setIcon(QIcon());
    }

    if ( (programas.count() > 1) && (programas.at(1) != "") )
    {
        GetProgram(programas.at(1));
        ui->pushButton_2->setText(tem1);
        ui->pushButton_2->setIcon(QIcon(tem2));
    }
    else
    {
        ui->pushButton_2->setText("");
        ui->pushButton_2->setIcon(QIcon());
    }

    if ( (programas.count() > 2) && (programas.at(2) != "") )
    {
        GetProgram(programas.at(2));
        ui->pushButton_3->setText(tem1);
        ui->pushButton_3->setIcon(QIcon(tem2));
    }
    else
    {
        ui->pushButton_3->setText("");
        ui->pushButton_3->setIcon(QIcon());
    }

    if ( (programas.count() > 3) && (programas.at(3) != "") )
    {
        GetProgram(programas.at(3));
        ui->pushButton_4->setText(tem1);
        ui->pushButton_4->setIcon(QIcon(tem2));
    }
    else
    {
        ui->pushButton_4->setText("");
        ui->pushButton_4->setIcon(QIcon());
    }

    if ( (programas.count() > 4) && (programas.at(4) != "") )
    {
        GetProgram(programas.at(4));
        ui->pushButton_5->setText(tem1);
        ui->pushButton_5->setIcon(QIcon(tem2));
    }
    else
    {
        ui->pushButton_5->setText("");
        ui->pushButton_5->setIcon(QIcon());
    }

    if ( (programas.count() > 5) && (programas.at(5) != "") )
    {
        GetProgram(programas.at(5));
        ui->pushButton_6->setText(tem1);
        ui->pushButton_6->setIcon(QIcon(tem2));
    }
    else
    {
        ui->pushButton_6->setText("");
        ui->pushButton_6->setIcon(QIcon());
    }

    if ( (programas.count() > 6) && (programas.at(6) != "") )
    {
        GetProgram(programas.at(6));
        ui->pushButton_7->setText(tem1);
        ui->pushButton_7->setIcon(QIcon(tem2));
    }
    else
    {
        ui->pushButton_7->setText("");
        ui->pushButton_7->setIcon(QIcon());
    }

    if ( (programas.count() > 7) && (programas.at(7) != "") )
    {
        GetProgram(programas.at(7));
        ui->pushButton_8->setText(tem1);
        ui->pushButton_8->setIcon(QIcon(tem2));
    }
    else
    {
        ui->pushButton_8->setText("");
        ui->pushButton_8->setIcon(QIcon());
    }

    if ( (programas.count() > 8) && (programas.at(8) != "") )
    {
        GetProgram(programas.at(8));
        ui->pushButton_9->setText(tem1);
        ui->pushButton_9->setIcon(QIcon(tem2));
    }
    else
    {
        ui->pushButton_9->setText("");
        ui->pushButton_9->setIcon(QIcon());
    }

    if ( (programas.count() > 9) && (programas.at(9) != "") )
    {
        GetProgram(programas.at(9));
        ui->pushButton_10->setText(tem1);
        ui->pushButton_10->setIcon(QIcon(tem2));
    }
    else
    {
        ui->pushButton_10->setText("");
        ui->pushButton_10->setIcon(QIcon());
    }


    if ( settings.value("Vertical","NO") == "YES" )
    {
        ui->pushButton_6->setEnabled(false);
        ui->pushButton_7->setEnabled(false);
        ui->pushButton_8->setEnabled(false);
        ui->pushButton_9->setEnabled(false);
        ui->pushButton_10->setEnabled(false);
    }
    else
    {
        ui->pushButton_6->setEnabled(true);
        ui->pushButton_7->setEnabled(true);
        ui->pushButton_8->setEnabled(true);
        ui->pushButton_9->setEnabled(true);
        ui->pushButton_10->setEnabled(true);
    }


}

Settings::~Settings()
{
    delete ui;
}

void Settings::GetProgram(QString file)
{
    QSettings settings("/usr/share/applications/hildon/" + file + ".desktop", QSettings::IniFormat);
    settings.beginGroup("Desktop Entry");
    QString name = settings.value("Name", "no name").toString();
    QString icon = settings.value("Icon", "no icon").toString();
    QString domain("maemo-af-desktop");
    if(settings.contains("X-Text-Domain"))
        domain = settings.value("X-Text-Domain").toString();
    name = QString::fromUtf8(dgettext(domain.toLatin1(), name.toLatin1()));


    QSettings settings2("/etc/hildon/theme/index.theme", QSettings::IniFormat);
    settings2.beginGroup("X-Hildon-Metatheme");
    QString tema = settings2.value("IconTheme", "hicolor").toString();
    tema = tema.trimmed();

    QString icono;
    if ( QFileInfo("/usr/share/icons/" + tema + "/64x64/hildon/" + icon + ".png").exists() )
        icono = "/usr/share/icons/" + tema + "/64x64/hildon/" + icon + ".png";
    else if ( QFileInfo("/usr/share/icons/" + tema + "/64x64/apps/" + icon + ".png").exists() )
        icono = "/usr/share/icons/" + tema + "/64x64/apps/" + icon + ".png";
    else if ( QFileInfo("/usr/share/icons/" + tema + "/48x48/hildon/" + icon + ".png").exists() )
        icono = "/usr/share/icons/" + tema + "/48x48/hildon/" + icon + ".png";
    else if ( QFileInfo("/usr/share/icons/" + tema + "/48x48/apps/" + icon + ".png").exists() )
        icono = "/usr/share/icons/" + tema + "/48x48/apps/" + icon + ".png";
    else if ( QFileInfo("/usr/share/icons/" + tema + "/scalable/hildon/" + icon + ".png").exists() )
        icono = "/usr/share/icons/" + tema + "/scalable/hildon/" + icon + ".png";
    else if ( QFileInfo("/usr/share/icons/" + tema + "/scalable/apps/" + icon + ".png").exists() )
        icono = "/usr/share/icons/" + tema + "/scalable/apps/" + icon + ".png";

    else if ( QFileInfo("/usr/share/icons/hicolor/64x64/hildon/" + icon + ".png").exists() )
        icono = "/usr/share/icons/hicolor/64x64/hildon/" + icon + ".png";
    else if ( QFileInfo("/usr/share/icons/hicolor/64x64/apps/" + icon + ".png").exists() )
        icono = "/usr/share/icons/hicolor/64x64/apps/" + icon + ".png";
    else if ( QFileInfo("/usr/share/icons/hicolor/48x48/hildon/" + icon + ".png").exists() )
        icono = "/usr/share/icons/hicolor/48x48/hildon/" + icon + ".png";
    else if ( QFileInfo("/usr/share/icons/hicolor/48x48/apps/" + icon + ".png").exists() )
        icono = "/usr/share/icons/hicolor/48x48/apps/" + icon + ".png";
    else if ( QFileInfo("/usr/share/icons/hicolor/scalable/hildon/" + icon + ".png").exists() )
        icono = "/usr/share/icons/hicolor/scalable/hildon/" + icon + ".png";
    else if ( QFileInfo("/usr/share/icons/hicolor/scalable/apps/" + icon + ".png").exists() )
        icono = "/usr/share/icons/hicolor/scalable/apps/" + icon + ".png";

    else if ( QFileInfo("/usr/share/pixmaps/" + icon + ".png").exists() )
        icono = "/usr/share/pixmaps/" + icon + ".png";
    else if ( QFileInfo("/opt/maemo/usr/share/pixmaps/" + icon + ".png").exists() )
        icono = "/opt/maemo/usr/share/pixmaps/" + icon + ".png";
    else icono = "/usr/share/icons/hicolor/64x64/hildon/tasklaunch_default_application.png";

    tem1 = name;
    tem2 = icono;


}


void Settings::on_pushButton_clicked()
{
    Items* it = new Items(0,0);
    it->exec(); it->close(); LoadAll();
}

void Settings::on_pushButton_2_clicked()
{
    Items* it = new Items(0,1);
    it->exec(); it->close(); LoadAll();
}

void Settings::on_pushButton_3_clicked()
{
    Items* it = new Items(0,2);
    it->exec(); it->close(); LoadAll();
}

void Settings::on_pushButton_4_clicked()
{
    Items* it = new Items(0,3);
    it->exec(); it->close(); LoadAll();
}

void Settings::on_pushButton_5_clicked()
{
    Items* it = new Items(0,4);
    it->exec(); it->close(); LoadAll();
}

void Settings::on_pushButton_6_clicked()
{
    Items* it = new Items(0,5);
    it->exec(); it->close(); LoadAll();
}

void Settings::on_pushButton_7_clicked()
{
    Items* it = new Items(0,6);
    it->exec(); it->close(); LoadAll();
}

void Settings::on_pushButton_8_clicked()
{
    Items* it = new Items(0,7);
    it->exec(); it->close(); LoadAll();
}

void Settings::on_pushButton_9_clicked()
{
    Items* it = new Items(0,8);
    it->exec(); it->close(); LoadAll();
}

void Settings::on_pushButton_10_clicked()
{
    Items* it = new Items(0,9);
    it->exec(); it->close(); LoadAll();
}


void Settings::on_checkBox_stateChanged(int )
{
    QSettings settings("cepiperez","homescreen-dockbar");
    if ( ui->checkBox->isChecked() )
        settings.setValue("Background","YES");
    else
        settings.setValue("Background","NO");
    settings.sync();
}

void Settings::on_pushButton_11_clicked()
{
    Home* hw = new Home(this, "Backimage", "/home/user/MyDocs");
    hw->exec();
}

void Settings::on_checkBox_2_stateChanged(int )
{
    QSettings settings("cepiperez","homescreen-dockbar");
    if ( ui->checkBox_2->isChecked() )
        settings.setValue("Autorotation","YES");
    else
        settings.setValue("Autorotation","NO");
    settings.sync();
}

void Settings::on_checkBox_3_stateChanged(int )
{
    QSettings settings("cepiperez","homescreen-dockbar");
    if ( ui->checkBox_3->isChecked() )
        settings.setValue("Vertical","YES");
    else
        settings.setValue("Vertical","NO");
    settings.sync();

    if ( settings.value("Vertical","NO") == "YES" )
    {
        ui->pushButton_6->setEnabled(false);
        ui->pushButton_7->setEnabled(false);
        ui->pushButton_8->setEnabled(false);
        ui->pushButton_9->setEnabled(false);
        ui->pushButton_10->setEnabled(false);
    }
    else
    {
        ui->pushButton_6->setEnabled(true);
        ui->pushButton_7->setEnabled(true);
        ui->pushButton_8->setEnabled(true);
        ui->pushButton_9->setEnabled(true);
        ui->pushButton_10->setEnabled(true);
    }

}
